@@ -47,37 +47,6 @@ def imresize(image, size):
   return cv2.resize(image, (size[1],size[0]))
 
 
-class DataIOThread(threading.Thread):
-  def __init__(self, func, data_queue):
-    super(DataIOThread, self).__init__()
-    self.func = func
-    self.data_queue = data_queue
-
-  def run(self):
-    for a, b in self.func():
-      self.data_queue.put((a, b))
-
-    self.data_queue.put((None,None))
-
-
-def dataset_thread(capacity_size=16):
-  def dataio_warp(func):
-    def warp_func(*args, **kwargs):
-      data_queue = queue.Queue(maxsize=capacity_size)
-      data_thread = DataIOThread(functools.partial(func, *args, **kwargs), data_queue)
-      data_thread.start()
-
-      while True:
-        a, b = data_queue.get()
-        if a is None and b is None:
-          raise StopIteration
-
-        yield a, b
-
-    return warp_func
-  return dataio_warp
-
-
 class Dataset(BaseNode):
   _BASE_DATASET = True
 
@@ -171,7 +140,7 @@ class Dataset(BaseNode):
   def unlabeled(self, tag=''):
     unlabeled_folder = os.path.join(self.dir, self.unlabeled_tag)
     if not os.path.exists(unlabeled_folder):
-      raise StopIteration
+      return None
 
     if not os.path.exists(os.path.join(self.dir, 'unlabeled_list.txt')):
       with open(os.path.join(self.dir, 'unlabeled_list.txt'), 'w') as fp:
@@ -202,14 +171,13 @@ class Dataset(BaseNode):
 
         line_content = fp.readline()
 
-    count = 0
+    data = []
     for file in unlabeled_list:
       if file not in has_labeled_list:
-        yield os.path.join(self.dir, self.unlabeled_tag, file), {'id': count, 'file_id': file}
+        data.append((os.path.join(self.dir, self.unlabeled_tag, file), {'id': len(data), 'file_id': file}))
 
-      count += 1
+    return data
 
-    raise StopIteration
 
   def make_candidate(self, unlabeled_file, label_file, status=''):
     # status: 'SKIP/OK'
@@ -270,6 +238,12 @@ class Dataset(BaseNode):
 
     return count
 
+  def waiting_process_num(self):
+    return 0
+
+  def finish_process_num(self):
+    return 0
+
   @property
   def ids(self):
     return self._ids
@@ -825,3 +799,46 @@ class Dataset(BaseNode):
             logger.error('perhaps %s must be prepared manully and '
                          'put it at %s'%(f, target_path))
             os._exit(-1)
+
+
+class UnlabeledDataset(Dataset):
+  def __init__(self, dataset):
+    super(UnlabeledDataset, self).__init__()
+    self.data = dataset.unlabeled()
+
+  def data_pool(self):
+    for a, b in self.data:
+      yield a, b
+
+  def at(self, id):
+    return self.data[id]
+
+  @property
+  def size(self):
+    return len(self.data)
+
+class DataAnnotationSplitDataset(object):
+  def __init__(self, dataset):
+      super().__init__()
+      self.dataset = dataset
+    
+  def data_pool(self):
+    pass
+
+  def at(self, id):
+    self.dataset.at(id)
+    pass
+
+  def annotation_at(self, id):
+    
+    return
+
+  @property
+  def size(self):
+    return len(self.dataset)
+
+  def waiting_process_num(self):
+    return self.dataset.waiting_process_num()
+
+  def finish_process_num(self):
+    return self.dataset.finish_process_num()
