@@ -17,7 +17,6 @@ except:
 import multiprocessing
 from antgo.task.task import *
 from antgo.dataflow.basic import *
-import scipy.misc
 import imageio
 import requests
 from antgo.context import *
@@ -159,7 +158,8 @@ class QueueRecorderNode(Node):
           os.makedirs(self.dump_dir)
 
         image_path = os.path.join(self.dump_dir, '%s.png'%str(uuid.uuid4()))
-        scipy.misc.imsave(image_path, transfer_result)
+        # scipy.misc.imsave(image_path, transfer_result)
+        imageio.imwrite(image_path, transfer_result)
         transfer_result = image_path
         transfer_result_type = 'IMAGE'
       elif result['%s_TYPE'%key] == 'VIDEO':
@@ -327,7 +327,8 @@ class LocalRecorderNode(Node):
         assert (data.shape[2] == 3)
         transfer_result = data.astype(np.uint8)
 
-      scipy.misc.imsave(os.path.join(self.dump_dir, '%d_%d_%s.png'%(count, index, name)), transfer_result)
+      # scipy.misc.imsave(os.path.join(self.dump_dir, '%d_%d_%s.png'%(count, index, name)), transfer_result)
+      imageio.imwrite(os.path.join(self.dump_dir, '%d_%d_%s.png'%(count, index, name)), transfer_result)
     elif data_type == 'VIDEO':
       video_path = os.path.join(self.dump_dir, '%d_%d_%s.mp4' % (count, index, name))
       writer = imageio.get_writer(video_path, fps=30)
@@ -401,28 +402,17 @@ class EmptyRecorderNode(Node):
     pass
 
 
-class LocalRecorderNodeV2(Node):
-  def __init__(self, inputs):
-    super(LocalRecorderNodeV2, self).__init__(name=None, action=self.action, inputs=inputs, auto_trigger=True)
-    self._annotation_cache = queue.Queue()
-
+class LocalRecorderNodeV2(object):
+  def __init__(self, callback=None):
+    super(LocalRecorderNodeV2, self).__init__()
     self._dump_dir = None
-    self._is_none = False
-
     self._count = 0
-    self._content = []
+    self._callback = callback
     setattr(self, 'model_fn', None)
 
-  @property
-  def content(self):
-    return self._content
-
   def close(self):
     pass
 
-  def clear(self):
-    self._content = []
-
   def save(self, data, data_type, name, count, index):
     # only support 'FILE', 'JSON', 'STRING', 'IMAGE', 'VIDEO', 'AUDIO'
     assert(data_type in ['FILE', 'JSON', 'SCALAR', 'STRING', 'IMAGE', 'VIDEO', 'AUDIO'])
@@ -436,15 +426,18 @@ class LocalRecorderNodeV2(Node):
       shutil.copy(data, os.path.join(self.dump_dir, file_name))
       return file_name
     elif data_type == 'JSON':
-      file_name = '%d_%d_%s.json'%(count, index,name)
-      with open(os.path.join(self.dump_dir, file_name),'w') as fp:
-        fp.write(json.dumps(data))
-      return file_name
+      # file_name = '%d_%d_%s.json'%(count, index,name)
+      # with open(os.path.join(self.dump_dir, file_name),'w') as fp:
+      #   fp.write(json.dumps(data))
+      # return file_name
+      if type(data) != str:
+        data = json.dumps(data)
+      return data
     elif data_type == 'STRING' or data_type == 'SCALAR':
-      file_name = '%d_%d_%s.txt'%(count, index,name)
-      with open(os.path.join(self.dump_dir, file_name), 'w') as fp:
-        fp.write(str(data))
-      return file_name
+      # file_name = '%d_%d_%s.txt'%(count, index,name)
+      # with open(os.path.join(self.dump_dir, file_name), 'w') as fp:
+      #   fp.write(str(data))
+      return str(data)
     elif data_type == 'IMAGE':
       transfer_result = data
       if len(data.shape) == 2:
@@ -455,11 +448,13 @@ class LocalRecorderNodeV2(Node):
           data_max = np.max(data)
           transfer_result = ((data - data_min) / (data_max - data_min) * 255).astype(np.uint8)
       else:
-        assert (data.shape[2] == 3)
+        assert (data.shape[2] == 3 or data.shape[2] == 4)
         transfer_result = data.astype(np.uint8)
 
       file_name = '%d_%d_%s.png'%(count, index, name)
-      scipy.misc.imsave(os.path.join(self.dump_dir, file_name), transfer_result)
+      # scipy.misc.imsave(os.path.join(self.dump_dir, file_name), transfer_result)
+      imageio.imwrite(os.path.join(self.dump_dir, file_name), transfer_result)
+
       return file_name
     elif data_type == 'VIDEO':
       file_name = '%d_%d_%s.mp4' % (count, index, name)
@@ -483,59 +478,68 @@ class LocalRecorderNodeV2(Node):
       self._annotation_cache.put(copy.deepcopy(entry))
 
   def record(self, val, **kwargs):
-    results = val
-    if type(val) != list and type(val) != tuple:
-      results = [val]
+    try:
+      results = val
+      if type(val) != list and type(val) != tuple:
+        results = [val]
 
-    group = []
-    for index, result in enumerate(results):
-      gt = None
-      if self._annotation_cache.qsize() > 0:
-        gt = self._annotation_cache.get()
+      for index, result in enumerate(results):
+        group = []
+        # 均转换成文件或字符串形式输出 [{'TYPE': 'FILE', 'PATH': ''},
+        #                           {'TYPE': 'JSON', 'CONTENT': ''},
+        #                           {'TYPE': 'STRING', 'CONTENT': ''},
+        #                           {'TYPE': 'IMAGE', 'PATH': ''},
+        #                           {'TYPE': 'VIDEO', 'PATH': ''},
+        #                           {'TYPE': 'AUDIO', 'PATH': ''}]
 
-      if gt is None and not self._is_none:
-        self._is_none = True
+        # 重新组织数据格式
+        data = {}
+        for key, value in result.items():
+          data_name = key
+          if data_name not in data:
+            data[data_name] = {}
+            data[data_name]['attribute'] = {}
+          
+          data[data_name]['title'] = data_name
+          if 'data' in value or 'DATA' in value:
+            if 'data' in value:
+              data[data_name]['data'] = value['data']
+            else:
+              data[data_name]['data'] = value['DATA']
 
-      # 均转换成文件或字符串形式输出 [{'TYPE': 'FILE', 'PATH': ''},
-      #                           {'TYPE': 'JSON', 'CONTENT': ''},
-      #                           {'TYPE': 'STRING', 'CONTENT': ''},
-      #                           {'TYPE': 'IMAGE', 'PATH': ''},
-      #                           {'TYPE': 'VIDEO', 'PATH': ''},
-      #                           {'TYPE': 'AUDIO', 'PATH': ''}]
+          if 'type' in value or 'TYPE' in value:
+            if 'type' in value:
+              data[data_name]['type'] = value['type']
+            else:
+              data[data_name]['type'] = value['TYPE']
 
-      # 重新组织数据格式
-      data = {}
-      for key, value in result.items():
-        xxyy = key.split('_')
-        data_name = xxyy[0]
+          # if(len(xxyy) == 1):
+          #   data[data_name]['data'] = value
+          #   data[data_name]['title'] = key
+          # elif xxyy[1] == 'TYPE':
+          #   data[data_name]['type'] = value
+          # else:
+          #   if type(value) == np.ndarray:
+          #     value = value.tolist()
+          #   data[data_name]['attribute'][key] = str(value)
 
-        if data_name not in data:
-          data[data_name] = {}
-          data[data_name]['attribute'] = {}
+        # 转换数据到适合web
+        for data_name, data_content in data.items():
+          data_content['data'] = self.save(data_content['data'],
+                              data_content['type'],
+                              data_content['title'],
+                              self._count,
+                              index)
 
-        if(len(xxyy) == 1):
-          data[data_name]['data'] = value
-          data[data_name]['title'] = key
-        elif xxyy[1] == 'TYPE':
-          data[data_name]['type'] = value
-        else:
-          if type(value) == np.ndarray:
-            value = value.tolist()
-          data[data_name]['attribute'][key] = str(value)
+          group.append(data_content)
 
-      # 转换数据到适合web
-      for data_name, data_content in data.items():
-        data_content['data'] = self.save(data_content['data'],
-                             data_content['type'],
-                             data_content['title'],
-                             self._count,
-                             index)
+        # 记录
+        if self._callback is not None:
+          self._callback([group])
 
-        group.append(data_content)
-
-    # 记录
-    self._content.append(group)
-    self._count += 1
+      self._count += 1
+    except:
+      logger.error('Record error.')
 
   @property
   def dump_dir(self):
