@@ -1,11 +1,13 @@
 # encoding=utf-8
 # @Time    : 17-3-3
-# @File    : common.py
+# @File    : main.py
 # @Author  : jian<jian@mltalker.com>
 from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 import sys
+# sys.path.append('/workspace/workspace/portrait_code/tool/antgo')
+# sys.path.append('/workspace/workspace/portrait_code/tool/antgo/antgo')
 from antgo.ant.shell import *
 from antgo.ant.generate import *
 from antgo.ant.demo import *
@@ -37,14 +39,11 @@ _ant_support_commands = ["train",
                          "challenge",
                          "activelearning",
                          "dataset",
-                         "batch",
+                         "predict",
                          "demo",
                          "browser",
                          "startproject",
-                         "config",
-                         "tools/tffrozen",
-                         "tools/tfrecords",
-                         "tools/tfgraph"]
+                         "config"]
 
 #############################################
 #######   antgo parameters            #######
@@ -54,7 +53,7 @@ flags.DEFINE_string('main_param', None, 'model parameters')
 flags.DEFINE_string('main_folder', None, 'resource folder')
 flags.DEFINE_string('version', None, 'minist antgo version')
 flags.DEFINE_string('task', None, 'task file')
-flags.DEFINE_string('dataset', None, 'dataset')
+flags.DEFINE_string('dataset', 'images_full', 'dataset')
 flags.DEFINE_string('signature', '123', 'signature')
 flags.DEFINE_string('devices', '', 'devices')
 flags.DEFINE_string('servers', '', '')
@@ -71,8 +70,8 @@ flags.DEFINE_string('restore_experiment', None, 'restore experiment')
 flags.DEFINE_string('factory', None, '')
 flags.DEFINE_string('config', None, 'config file')
 flags.DEFINE_string('benchmark', None, 'benchmark experiments')
-flags.DEFINE_string('host_ip', '127,0.0.1', 'host ip address')
-flags.DEFINE_integer('host_port', 10000, 'port')
+flags.DEFINE_string('host_ip', '127.0.0.1', 'host ip address')
+flags.DEFINE_integer('host_port', 8909, 'port')
 flags.DEFINE_string('html_template', None, 'html template')
 flags.DEFINE_string('option', '', '')
 flags.DEFINE_indicator('worker', '')
@@ -80,12 +79,6 @@ flags.DEFINE_indicator('master', '')
 flags.DEFINE_indicator('unlabel', '')
 flags.DEFINE_indicator('skip_training', '')
 flags.DEFINE_string('running_platform', 'local', 'local/cloud')
-#############################################
-########  tools - tffrozen            #######
-#############################################
-flags.DEFINE_string('tffrozen_input_nodes', '', 'input node names in graph')
-flags.DEFINE_string('tffrozen_output_nodes', '', 'output node names in graph')
-flags.DEFINE_string('tfgraph_path', '', 'pb file path')
 
 FLAGS = flags.AntFLAGS
 Config = config.AntConfig
@@ -135,7 +128,6 @@ def main():
   # 解析配置文件
   config_xml = os.path.join(os.environ['HOME'], '.config', 'antgo', 'config.xml')
   Config.parse_xml(config_xml)
-
   if len(sys.argv) == 1 or sys.argv[1].startswith('-'):
     # interactive control
     shell_process = AntShell(Context(), token)
@@ -230,16 +222,11 @@ def main():
 
     return
 
-  if ant_cmd == 'tools/tfgraph':
-    import antgo.codebook.tf.tftools as tftools
-    tftools.tftool_visualize_pb(FLAGS.tfgraph_path())
-    return
-
   # 7.step check related params
   # 7.1 must set name
   name = FLAGS.name()
   if name is None:
-    logger.error('must set name')
+    logger.error('Must set experiemnt name.')
     return
 
   # 7.2 check main folder (all related model code, includes main_file and main_param)
@@ -302,8 +289,12 @@ def main():
   main_param = FLAGS.main_param()
   if main_param is not None:
     main_config_path = os.path.join(main_folder, main_param)
-    params = yaml.load(open(main_config_path, 'r'))
-    ant_context.params = params
+    try:
+      with open(main_config_path, 'r') as fp:
+        params = yaml.load(fp, Loader=yaml.FullLoader)
+        ant_context.params = params
+    except:
+      print('Fail to load main_param %s.'%main_param)
 
   ant_context.name = name
   ant_context.data_factory = data_factory
@@ -327,27 +318,6 @@ def main():
 
   # time stamp
   time_stamp = timestamp()
-  # tools
-  if ant_cmd == 'tools/tffrozen':
-    # tensorflow tools
-    import antgo.codebook.tf.tftools as tftools
-    tftools.tftool_frozen_graph(ant_context,
-                                dump_dir,
-                                time_stamp,
-                                FLAGS.tffrozen_input_nodes(),
-                                FLAGS.tffrozen_output_nodes())
-    return
-  elif ant_cmd == 'tools/tfrecords':
-    # tensorflow tools
-    import antgo.codebook.tf.tftool_records as tftool_records
-    tfrecords = \
-        tftool_records.AntTFRecords(ant_context,
-                                    data_factory,
-                                    dataset,
-                                    dump_dir)
-    tfrecords.start()
-    return
-
   if ant_cmd == "train":
     with running_sandbox(sandbox_time=FLAGS.max_time(),
                          sandbox_dump_dir=main_folder,
@@ -404,7 +374,7 @@ def main():
                               devices=FLAGS.devices())
 
     running_process.start()
-  elif ant_cmd == "batch":
+  elif ant_cmd == "predict":
     running_process = AntBatch(ant_context,
                                name,
                                FLAGS.host_ip(),
